@@ -126,10 +126,10 @@ def cut_subtitles(
     inp = timeline.inp
     chunks = timeline.chunks
 
-    if chunks is None:
-        log.error("Timeline too complex")
-
     for s, sub in enumerate(inp.subtitles):
+        if chunks is None:
+            log.error("Timeline too complex for subtitles")
+
         file_path = os.path.join(temp, f"{s}s.{sub.ext}")
         new_path = os.path.join(temp, f"new{s}s.{sub.ext}")
 
